#[repr(C)]pub struct LuaStackCheck {
pub m_L: *mut lua_State,
pub m_Filename: *const i8,
pub m_Linenumber: i32,
pub m_Top: i32,
pub m_Diff: i32,
}Expand description
LuaStackCheck struct. Internal
LuaStackCheck utility to make sure we check the Lua stack state before leaving a function. m_Diff is the expected difference of the stack size.
Fields
m_L: *mut lua_StateThe Lua state to check
m_Filename: *const i8Debug info in case of an assert
m_Linenumber: i32m_Top: i32The current top of the Lua stack (from lua_gettop())
m_Diff: i32The expected difference in stack size when this sctruct goes out of scope
Implementations